/* 
 * reset netlib (reset-netlib.c) 
 * a tool for resetting the Palm/Treo network stack
 * copyright (c) 2005, daniel grobe sachs <dgsachs@nekito.net>
 *
 * This is free software. See included LICENSE file for details.
 */

/***********************************************************************
 hello.c - Sample "Hello, world!" program for Palm OS.  Build with
 	PRC-Tools 2.0 and Palm OS SDK 3.5 or better.

 Created 2001.02.04 by Warren Young
 $Revision: 1.1 $  $Date: 2001/09/25 08:36:32 $

 This program is hereby placed into the public domain.
***********************************************************************/

#include <PalmOS.h>

#include "resource.h"
#define COUNT 16

////////////////////////////////////////////////////////////////////////
// Globals

// Pointer to the currently-active form
static FormPtr gpForm;


//// StartApplication //////////////////////////////////////////////////
// Called when application is starting

static Err StartApplication() 
{
	return 0;
}


//// StopApplication ///////////////////////////////////////////////////
// Called when application is being shut down.

static void StopApplication() 
{
	FrmCloseAllForms();
}


//// ApplicationEventHandler /////////////////////////////////////////////
// Handle global events, and pass form-specific events to each form's
// event handler.

static Boolean ApplicationEventHandler(EventPtr event) 
{
	Boolean handled = false;

	Err err;
	UInt16 netLibRefNum;

	switch (event->eType) {
		default:
			// -Wall warning eater: switch must handle all enum
			// elements.
			break;
	}

	return handled;
}


//// EventLoop /////////////////////////////////////////////////////////
// Global event loop.

static void EventLoop() 
{
	EventType event;
	UInt16 error;
	do {
		EvtGetEvent(&event, evtWaitForever);
		
		if (!SysHandleEvent(&event)) {
			if (!MenuHandleEvent(0, &event, &error)) {
				if (!ApplicationEventHandler(&event)) {
					FrmDispatchEvent(&event);
				}
			}
		}
	}
	while (event.eType != appStopEvent);
}


//// PilotMain /////////////////////////////////////////////////////////
// It all starts here...

UInt32 PilotMain(UInt16 launchCode, MemPtr cmdPBP, UInt16 launchFlags) 
{
	Err err = 0;
	UInt16 netLibRefNum, interfaceError;
	EventType event;

	int i;

	if (launchCode == sysAppLaunchCmdNormalLaunch) {
		// Reset network library
		
		err = SysLibFind("Net.lib",&netLibRefNum);
		
#if 0
		if( !err )
                	err = NetLibOpen(netLibRefNum, &interfaceError);
#endif

		if( !err )
		{
			for( i = 0; i < COUNT; i++ )
			{
				err = NetLibClose(netLibRefNum,true);
				if( !err ) 
					break;
			}

			err = NetLibFinishCloseWait(netLibRefNum);
		}

		if( !err ) 
		{
			FrmAlert(AboutAlert);
		}

		StopApplication();

		// Post a AppStopEvent
	
		MemSet( &event, sizeof(event), 0);
	
		event.eType = appStopEvent;
		EvtAddEventToQueue(&event);
	}


	return err;
}

